@@ -74,21 +74,38 @@ class ImageRecognition(object):
         
         out = None
         with slim.arg_scope(resnet_arg_scope()):
-            out, end_points = resnet_v2_101(inputs = input_tensor,
+            out, end_points = resnet_v2_152(inputs = input_tensor,
                                             num_classes=1001,
                                             is_training=is_training,
                                             global_pool=True,
                                             output_stride=None,
                                             spatial_squeeze=True,
                                             reuse=None,
-                                            scope='resnet_v2_101')
+                                            scope='resnet_v2_152')
             base_var_list = tf.get_collection(tf.GraphKeys.GLOBAL_VARIABLES)
+            print ("----------------------------->>>", out)
         
-        with tf.variable_scope('resnet_v2_101'):
+        with tf.variable_scope('resnet_v2_152'):
             depth = out.get_shape().as_list()[1] *  out.get_shape().as_list()[2] * out.get_shape().as_list()[3]
-            out = new_fc_layer(out, 
+            
+            if self.classification_by_regression: 
+                out = new_fc_layer(out, 
                                 num_inputs = depth, 
-                                num_outputs = len(self.classes), 
+                                num_outputs = 1, 
+                                name = 'fc1', 
+                                dropout_val= 1 - dropout_rate, 
+                                activation="NONE",
+                                lrelu_alpha=0.2, 
+                                data_type=tf.float32,
+                                is_training=is_training,
+                                use_bias=False)
+                out = 6 /(1 + tf.exp(-0.2 * out)) - 3
+                out = tf.concat([out, 1.0 - out], 1)
+
+            else: 
+                out = new_fc_layer(out, 
+                                num_inputs = depth, 
+                                num_outputs = 2, 
                                 name = 'fc1', 
                                 dropout_val= 1 - dropout_rate, 
                                 activation="NONE",
@@ -97,10 +114,6 @@ class ImageRecognition(object):
                                 is_training=is_training,
                                 use_bias=False)
 
-            if self.classification_by_regression: 
-                out = 6 /(1 + tf.exp(-0.2 * out)) - 3
-
-            else: 
                 if len(self.classes) == 1:
                     out = tf.nn.sigmoid(out)
                 else:
@@ -170,7 +183,24 @@ class ImageRecognition(object):
             
             depth = out.get_shape().as_list()[1] *  out.get_shape().as_list()[2] * out.get_shape().as_list()[3]
             out = tf.reshape(out, [tf.shape(out)[0], -1])
-            out = new_fc_layer(out, 
+            
+            if self.classification_by_regression:
+                out = new_fc_layer(out, 
+                                num_inputs = depth, 
+                                num_outputs = 1, 
+                                name = 'fc1', 
+                                dropout_val=1, 
+                                activation="NONE",
+                                lrelu_alpha=0.2, 
+                                data_type=tf.float32,
+                                is_training=is_training,
+                                use_bias=False)
+
+                out = 6 /(1 + tf.exp(-0.2 * out)) - 3
+                out = tf.concat([out, 1.0 - out], 1)
+            
+            else: 
+                out = new_fc_layer(out, 
                                 num_inputs = depth, 
                                 num_outputs = len(self.classes), 
                                 name = 'fc1', 
@@ -181,10 +211,6 @@ class ImageRecognition(object):
                                 is_training=is_training,
                                 use_bias=False)
 
-            if self.classification_by_regression:
-                out = 6 /(1 + tf.exp(-0.2 * out)) - 3
-            
-            else: 
                 if len(self.classes) == 1:
                     out = tf.nn.sigmoid(out)
                 else:
@@ -239,7 +265,23 @@ class ImageRecognition(object):
             depth =  out.get_shape().as_list()[1] *  out.get_shape().as_list()[2] * out.get_shape().as_list()[3]
             out = tf.reshape(out, [tf.shape(out)[0], -1])
 
-            out = new_fc_layer(out, 
+            if self.classification_by_regression:
+                out = new_fc_layer(out, 
+                                    num_inputs = depth, 
+                                    num_outputs = 1, 
+                                    name = 'fc1', 
+                                    dropout_val=1 - dropout_rate, 
+                                    activation="NONE",
+                                    lrelu_alpha=0.2, 
+                                    data_type=tf.float32,
+                                    is_training=is_training,
+                                    use_bias=False)
+
+                out = 6 /(1 + tf.exp(-0.2 * out)) - 3
+                out = tf.concat([out, 1.0 - out], 1)
+
+            else: 
+                out = new_fc_layer(out, 
                                     num_inputs = depth, 
                                     num_outputs = len(self.classes), 
                                     name = 'fc1', 
@@ -250,10 +292,6 @@ class ImageRecognition(object):
                                     is_training=is_training,
                                     use_bias=False)
 
-            if self.classification_by_regression:
-                out = 6 /(1 + tf.exp(-0.2 * out)) - 3
-
-            else: 
                 if len(self.classes) == 1:
                     out = tf.nn.sigmoid(out)
                 else:
